@@ -115,11 +115,6 @@ export const globalSettings = {
           type: yup.boolean(),
           defaultValue: true,
         },
-        hideUpcomingVaccines: {
-          description: 'Hide upcoming vaccines behind a button from the patient details page',
-          type: yup.boolean(),
-          defaultValue: false,
-        },
         enablePatientDeaths: {
           description: 'Enable death module',
           type: yup.boolean(),
@@ -250,6 +245,11 @@ export const globalSettings = {
               defaultValue: false,
               unit: 'seconds',
             },
+            dischargeDiagnosisMandatory: {
+              description: 'Require at least one diagnosis to be selected before discharging',
+              type: yup.boolean(),
+              defaultValue: false,
+            },
           },
         },
       },
